# PulpAnsibleClient::DistributionsAnsibleApi

All URIs are relative to *http://localhost:24817*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](DistributionsAnsibleApi.md#create) | **POST** /pulp/api/v3/distributions/ansible/ansible/ | Create an ansible distribution
[**delete**](DistributionsAnsibleApi.md#delete) | **DELETE** {ansible_distribution_href} | Delete an ansible distribution
[**list**](DistributionsAnsibleApi.md#list) | **GET** /pulp/api/v3/distributions/ansible/ansible/ | List ansible distributions
[**partial_update**](DistributionsAnsibleApi.md#partial_update) | **PATCH** {ansible_distribution_href} | Partially update an ansible distribution
[**read**](DistributionsAnsibleApi.md#read) | **GET** {ansible_distribution_href} | Inspect an ansible distribution
[**update**](DistributionsAnsibleApi.md#update) | **PUT** {ansible_distribution_href} | Update an ansible distribution



## create

> AsyncOperationResponse create(data)

Create an ansible distribution

Trigger an asynchronous create task

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::DistributionsAnsibleApi.new
data = PulpAnsibleClient::AnsibleAnsibleDistribution.new # AnsibleAnsibleDistribution | 

begin
  #Create an ansible distribution
  result = api_instance.create(data)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling DistributionsAnsibleApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **data** | [**AnsibleAnsibleDistribution**](AnsibleAnsibleDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(ansible_distribution_href)

Delete an ansible distribution

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::DistributionsAnsibleApi.new
ansible_distribution_href = 'ansible_distribution_href_example' # String | URI of Ansible Distribution. e.g.: /pulp/api/v3/distributions/ansible/ansible/1/

begin
  #Delete an ansible distribution
  result = api_instance.delete(ansible_distribution_href)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling DistributionsAnsibleApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_distribution_href** | **String**| URI of Ansible Distribution. e.g.: /pulp/api/v3/distributions/ansible/ansible/1/ | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> InlineResponse2003 list(opts)

List ansible distributions

ViewSet for Ansible Distributions.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::DistributionsAnsibleApi.new
opts = {
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  name: 'name_example', # String | 
  name__in: 'name__in_example', # String | Filter results where name is in a comma-separated list of values
  base_path: 'base_path_example', # String | 
  base_path__contains: 'base_path__contains_example', # String | Filter results where base_path contains value
  base_path__icontains: 'base_path__icontains_example', # String | Filter results where base_path contains value
  base_path__in: 'base_path__in_example', # String | Filter results where base_path is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List ansible distributions
  result = api_instance.list(opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling DistributionsAnsibleApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **name** | **String**|  | [optional] 
 **name__in** | **String**| Filter results where name is in a comma-separated list of values | [optional] 
 **base_path** | **String**|  | [optional] 
 **base_path__contains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__icontains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__in** | **String**| Filter results where base_path is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(ansible_distribution_href, data)

Partially update an ansible distribution

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::DistributionsAnsibleApi.new
ansible_distribution_href = 'ansible_distribution_href_example' # String | URI of Ansible Distribution. e.g.: /pulp/api/v3/distributions/ansible/ansible/1/
data = PulpAnsibleClient::AnsibleAnsibleDistribution.new # AnsibleAnsibleDistribution | 

begin
  #Partially update an ansible distribution
  result = api_instance.partial_update(ansible_distribution_href, data)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling DistributionsAnsibleApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_distribution_href** | **String**| URI of Ansible Distribution. e.g.: /pulp/api/v3/distributions/ansible/ansible/1/ | 
 **data** | [**AnsibleAnsibleDistribution**](AnsibleAnsibleDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## read

> AnsibleAnsibleDistribution read(ansible_distribution_href, opts)

Inspect an ansible distribution

ViewSet for Ansible Distributions.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::DistributionsAnsibleApi.new
ansible_distribution_href = 'ansible_distribution_href_example' # String | URI of Ansible Distribution. e.g.: /pulp/api/v3/distributions/ansible/ansible/1/
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an ansible distribution
  result = api_instance.read(ansible_distribution_href, opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling DistributionsAnsibleApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_distribution_href** | **String**| URI of Ansible Distribution. e.g.: /pulp/api/v3/distributions/ansible/ansible/1/ | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**AnsibleAnsibleDistribution**](AnsibleAnsibleDistribution.md)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(ansible_distribution_href, data)

Update an ansible distribution

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: Basic
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::DistributionsAnsibleApi.new
ansible_distribution_href = 'ansible_distribution_href_example' # String | URI of Ansible Distribution. e.g.: /pulp/api/v3/distributions/ansible/ansible/1/
data = PulpAnsibleClient::AnsibleAnsibleDistribution.new # AnsibleAnsibleDistribution | 

begin
  #Update an ansible distribution
  result = api_instance.update(ansible_distribution_href, data)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling DistributionsAnsibleApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_distribution_href** | **String**| URI of Ansible Distribution. e.g.: /pulp/api/v3/distributions/ansible/ansible/1/ | 
 **data** | [**AnsibleAnsibleDistribution**](AnsibleAnsibleDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[Basic](../README.md#Basic)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

